完美的世界 (豆瓣)
Description: 完美的世界电影简介和剧情介绍,完美的世界影评、图片、预告片、影讯、论坛、在线购票
Keywords: 完美的世界,A Perfect World,完美的世界影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.119豆瓣电影Top250

# 完美的世界 A Perfect World (1993)

导演: 克林特·伊斯特伍德
编剧: 约翰·李·汉考克
主演: 凯文·科斯特纳 / 劳拉·邓恩 / 克林特·伊斯特伍德 / T·J·劳瑟 / 基斯·斯扎拉巴基克
类型: 剧情 / 犯罪
官方网站: https://www.warnerbros.com/movies/perfect-world/
制片国家/地区: 美国
语言: 英语
上映日期: 1993-11-24(美国)
片长: 138分钟 / 125分钟(德国电视版)
又名: 强盗保镳
IMDb: tt0107808
豆瓣评分
引用
9.1
296417人评价
5星
63.8%
4星
30.2%
3星
5.4%
2星
0.4%
1星
0.1%
好于 99% 犯罪片
好于 98% 剧情片
想看 看过
评价:
推荐

## 完美的世界的剧情简介 · · · · · ·

单亲孩子菲利普·佩里（T·J·劳瑟 T.J. Lowther 饰）的母亲对他管教甚严，8岁的小菲利普甚至从未参加过一次鬼节讨糖果的游戏。附近州监狱的两名罪犯越狱成功，劫持了菲利普作为人质，向德州边界逃窜。途中，罪犯之一的布奇（凯文·科斯特纳 Kevin Costner 饰）干掉了鲁莽愚蠢的同伙，却对小菲利普照顾有加。与此同时，德州警探瑞德（克林特·伊斯特伍德 Clint Eastwood 饰）带着手下和州长特派的犯罪专家萨利（劳拉·邓恩 Laura Dern 饰）一同火速追捕布奇。双方在德克萨斯州境内展开了一场公路赛大竞技；而小菲利普也经历了很多从未想过过的刺激与快乐，并与布奇产生了一种近似父子的不寻常感情…… ©豆瓣

## 完美的世界的演职员 · · · · · · ( 全部 47 )

- 克林特·伊斯特伍德 导演
- 凯文·科斯特纳 演员
- 劳拉·邓恩 演员
- 克林特·伊斯特伍德 演员
- T·J·劳瑟 演员
- 基斯·斯扎拉巴基克 演员

## 完美的世界的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片505 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  猫鼠游戏

  末路狂花

  杀人回忆

  血钻

  七宗罪

  熔炉

  恐怖直播

  可可西里

  非常嫌疑犯

  上帝之城

我要写短评

## 完美的世界的短评 · · · · · · ( 全部 74341 条 )

热门 / 最新 / 好友

### 5972 有用 Doublebitch 看过 2011-02-18 16:47:15

我只杀过两个人，一个伤害了我妈妈，一个伤害了你

### 2369 有用 裸踝 看过 2008-12-15 14:09:09

他看见他，他带走他，就像带走童年的自己。他终于相信这个世界有鬼了，眼前这个开枪打伤他的小鬼就是童年自己的鬼魅。“再见，这是完美之旅。”再见，布奇。

### 1538 有用 十个斗的眼窝浅 看过 2012-07-23 23:19:54

他杀过人，却未动手打过一下菲利普，这段通往地狱的旅行过程中，当他看到妈妈因为怕孩子把新车弄脏而打骂孩子；爷爷嫌孙子动作慢而对孙子抬手耳刮子时，眼底的愤怒与不屑、憎恨与仇视，皆因他拥有一个对任何人都拳脚相加的父亲。这段近似父子的不寻常感情在影片结尾得到升华，我亦哭得稀里哗啦！

### 1340 有用 小斑 看过 2011-03-19 21:50:46

遥远的记忆啊……每次看的时候都想如果Kevin要我做人质，一定张开双手欢迎，然后收紧两臂学足无尾熊的样子抱住他的大腿死都不放。有他当爹，再有Eastwood当爷爷，就是一个perfect world了。肚腩长在有些人身上莫名地就成了一块萌肉

### 890 有用 安蓝·怪伯爵𓆝𓆟𓆜 看过 2015-02-09 01:09:03

史上最泪奔斯德哥尔摩综合征。我这辈子只杀过两个人，一个伤害了我妈妈一个伤害了你。情感创伤带来贴心信任，一对陌生人手拉手踏上没有希望看不到终点的迷途，Butch对Buzz的每一个小动作，摸摸头，拍拍屁股，看一眼心就化了~满满的父爱，已哭瞎。20171111小西天二刷依然哭到抽……

> 更多短评 74341条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 完美的世界的影评 · · · · · · ( 全部 1103 条 )

热门 / 最新 / 好友
小慢 2006-04-27 18:18:19

## 永远不要有结束

完美的世界 By 饭小鳗 片名：完美的世界（A Perfect World） 导演：克林特•伊斯特伍德 (Clint Eastwood) 主演：凯文•科斯特纳（Kevin Costner） 　　 克林特•伊斯特伍德（Clint Eastwood) ——如果你觉得这世界快乐，它就是天堂；如果你觉得这世界痛苦，那就是地... (展开)
2109 107 362回应 收起
凡tastics 2007-09-10 20:44:35

## 与电影同行 与完美擦肩

镜头一：越狱犯的闯入打破了清教徒家庭平静得没有生气的生活。布奇让菲利普捡起地上的枪，瞄准自己。“Perfect！”，布奇对菲利普说，来自暴徒的，出乎意料的肯定与赞美。这是他们的第一次见面，也是整部影片中第一次出现“完美”。 镜头二：市政厅外，一个小官员聒噪地在瑞德... (展开)
1407 45 90回应 收起
农民老郑🌈 2009-08-08 16:01:12

## 我伤心的就是这世界其实一点都不完美。

当菲利普小小的手和海恩斯大大的手握在一起时，泪腺开始决堤。泪点一向很低，在台风天里更是低到尘埃里。好吧，让我哭死好了。 当菲利普那笃信耶和华见证教的瘦弱妈妈夹着他走出草地时，小男孩发出弱弱的呼喊“布奇”、“布奇”，分外不舍，眼泪大颗大颗往下掉，其时我正在大口... (展开)
907 46 95回应 收起
momo 2009-03-10 13:03:41

## 《完美的世界》------ 他为我们带来

昨晚CCTV6又播了《完美的世界》，前一次播时看到的几个片段留给我大大的好感，于是这次当然要补课。可是人却很不争气，居然特别困，强打精神的看完，只能遗憾没能全神贯注，细致投入了。但这不影响我爱这部电影，很热爱。 逃犯和人质小男孩的故事，本来就足够有张... (展开)
198 16 20回应 收起
竹川克制子 2014-04-11 00:36:46

## 上帝只有一个，你以为你是谁啊？

这篇影评可能有剧透

好久没有这样酣畅淋漓地哭过了。 『A Perfect World』的导演太会煽情，惹得我又开始笨头笨脑地学写影评了。 好像影评和观后感也是有区别的。所以我还是先装模作样地评价一下整部电影的安排好了。 整个影片的进程是不拖沓的，剧情一直比较紧凑也不显得... (展开)
170 52回应 收起
酒仙桥14号 2020-03-09 10:24:41

## 16万人评分9.1，这部影史经典，我不忍心看第二遍

这篇影评可能有剧透

电影中的父爱，有各种各种的表现形式。 《当幸福来敲门》教会我们乐观向上；《摔跤吧！爸爸》告诫我们不懈坚持；《大鱼》为我们插上想象力的翅膀。 还有今年初在国内上映，被无数人奉为影史经典的《美丽人生》，以一段浪漫而残忍的父子情赚足观众的眼泪。 今天介绍的这部电影，... (展开)
84 1 5回应 收起
大-燕-威-王 2009-02-05 20:28:50

## 记一个不折不扣的好人

只能说，结局哭得我死去活来。 这是一个生活在规矩大人世界中的孩子，同一个童心未泯渴望幸福童年的大人之间的故事。 整部电影中，男主角逃犯布奇在小男孩面前始终用“游戏”这种方式，去犯一些无伤大雅的罪过。 一个罪犯，并不一定罪恶滔天。 那些不是罪犯的人，也并非就像一... (展开)
76 5 3回应 收起
东风七里 2011-07-28 09:18:10

## 童年、父爱和时光机

这篇影评可能有剧透

忽然之间，不知如何下笔了。对这部我看了两次的电影。第一次是很多人，第二次是我一个人。导演们真的很爱拍关于父爱的电影，这或许跟他们的童年经历有关。童年对个人来说，是最美好又是最重要的。第69届奥斯卡最佳外语片《给我一个爸》中，卢卡带着他的假儿子生活。《当幸福来... (展开)
57 3回应 收起
工藤新一 2017-06-03 09:54:21

## 完美的世界

"这是一辆偷来的时光飞船，哦不，只是暂时借用。加速，是通往未来，减速，是回到过去。当你停下来的时候，你需要享受现在的生活，我们是穿越德州的时光旅行者！” 毫无疑问这绝对是枚重磅催泪弹，公路片的基调，一些伴我同行的影子，故事其实相当简单，但是没有被本身的俗套剧... (展开)
40 1 0回应 收起
轻寻到下绿 2017-07-19 13:37:11

## 天使般美丽的情感

声色光影的世界里，科斯特纳将一个斯德哥尔摩综合症的逃犯演绎的如此细腻，除了感叹老爷子（伊斯特伍德）选角方面的正确抉择，和科斯特纳及其他演员的精湛演技离不开。影片中没有典型的好莱坞大制作，反而是适中透露着一股朴实的乡村气息，让观众得以将全部的注意力都集中在影... (展开)
24 3 0回应 收起

> 更多影评 1103篇

添加新讨论

## 讨论区 · · · · · ·

布奇真的想杀那个黑人吗 | 来自大白糖 | 6 回应 | 2022-11-19 21:53:58
小孩为什么开枪打布奇啊 | 来自飞鱼 | 1 回应 | 2022-11-17 01:46:49
为什么不抓了布奇的职业罪犯老爸而是重判他进少管... | 来自想做熊的孩子 | 3 回应 | 2022-11-05 15:28:23
没人注意到电影中的那个宗教“耶和华见证人”吗？ | 来自习阳 | 15 回应 | 2022-11-05 00:27:22
我只想问有一段他们像奥特曼一样的打招呼手势是干嘛 | 来自恋爱冲段选手 | 1 回应 | 2022-11-05 00:22:44

> 去这部影片的讨论区（全部245条）

## 关于《完美的世界》的问题 · · · · · · ( 全部15个 )

- 布奇的爸爸到底是怎样的人？布奇是惯犯吗？ 5人回答
- 布奇和瑞德以前就认识？ 2人回答

> 全部15个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)
- 极品电影 (waking forest)
- [佳作拾遗]是金子总要发光的 (Mitt)

## 谁在看这部电影 · · · · · ·

- 一期一会
  6分钟前 看过
- 胡杨
  14分钟前 看过
- 豆友19982488
  15分钟前 看过

416577人看过 / 348562人想看

订阅完美的世界的评论:
feed: rss 2.0